==> joytran-0.8.1.tar.bz2: joytran-0.8.1/src/handle_args.c <==
extern char *filename;
extern char *profile;
extern int want_daemon;
extern int verbosity;

int handle_args(int argc, char **argv) {

  int x = 0;
  int args = argc - 1;
  int f = 0, p = 0, d = 0, b = 0, q = 0, s = 0, v = 0, h = 0, n = 0;

  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-f") == 0) { f = 1; }
    else if (strcmp(argv[x], "-p") == 0) { p = 1; }
    else if (strcmp(argv[x], "-d") == 0) { d = 1; }
    else if (strcmp(argv[x], "-b") == 0) { b = 1; }
    else if (strcmp(argv[x], "-q") == 0) { q = 1; }
    else if (strcmp(argv[x], "-n") == 0) { n = 1; }
    else if (strcmp(argv[x], "-s") == 0) { s = 1; }
    else if (strcmp(argv[x], "-v") == 0) { v = 1; }
    else if (strcmp(argv[x], "-h") == 0) { h = 1; }
    else if (strcmp(argv[x], "-help") == 0) { h = 1; }
    else if (strcmp(argv[x], "--help") == 0) { h = 1; }
  }
  if (f == 1 && p == 1) {
    printf("can't specify both -f and -p"); exit(-1);
  }
  else if (d == 1 && b == 1) {
    printf("can't specify both -d and -b"); exit(-1);
  }
  else if (q == 1 && v == 1) {
    printf("can't specify both -q and -v"); exit(-1);
  }
  else if (q == 1 && s == 1) {
    printf("can't specify both -q and -s"); exit(-1);
  }
  else if (s == 1 && v == 1) {
    printf("can't specify both -s and -v"); exit(-1);
  }
  else if (q == 1 && n == 1) {
    printf("can't specify both -q and -n"); exit(-1);
  }
  else if (s == 1 && n == 1) {
    printf("can't specify both -s and -n"); exit(-1);
  }
  else if (v == 1 && n == 1) {
    printf("can't specify both -v and -n"); exit(-1);
  }

  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-f") == 0) {
      if (args > x) { filename = argv[x + 1]; }
      else { printf("need -f name_of_configuration_file"); exit(-1); }
    }
  }
  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-p") == 0) {
      if (args > x) { profile = argv[x + 1]; }
      else { printf("need -p name_of_profile"); exit(-1); }
    }
  }

  if (h == 1) {
    puts("Usage: joytran [option]\n");

    puts("-h/--help               help (this)");
    puts("-s / -q / -n / -v       silent / quiet / normal / verbose");
    puts("-b / -d                 background / daemon");
    puts("-f file / -p name       config_file / profile\n");

    puts("mail bug reports and suggestions to beyert@cs.ucr.edu");
    exit(0);
  }

  if (v == 1) { verbosity = 2; }
  else if (q == 1) { verbosity = 0; }
  else if (s == 1) { verbosity = -1; }
  else { verbosity = 1; }

  if (p == 0) {
    profile = "default";
  }

  if (f == 0) {
    filename = getenv("HOME");
    strcat(filename, "/.joytran/");
    strcat(filename, profile);
  }

  want_daemon = 0;
  if (d == 1) { want_daemon = 1; }
  else if (b == 1) { want_daemon = 0; }

  return 0;
}

==> joytran-0.8.2.tar.bz2: joytran-0.8.2/src/handle_args.c <==
extern char *filename;
extern char *profile;
extern int want_daemon;
extern int verbosity;

int handle_args(int argc, char **argv) {

  int x = 0;
  int args = argc - 1;
  int f = 0, p = 0, d = 0, b = 0, q = 0, s = 0, v = 0, h = 0, n = 0;

  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-f") == 0) { f = 1; }
    else if (strcmp(argv[x], "-p") == 0) { p = 1; }
    else if (strcmp(argv[x], "-d") == 0) { d = 1; }
    else if (strcmp(argv[x], "-b") == 0) { b = 1; }
    else if (strcmp(argv[x], "-q") == 0) { q = 1; }
    else if (strcmp(argv[x], "-n") == 0) { n = 1; }
    else if (strcmp(argv[x], "-s") == 0) { s = 1; }
    else if (strcmp(argv[x], "-v") == 0) { v = 1; }
    else if (strcmp(argv[x], "-h") == 0) { h = 1; }
    else if (strcmp(argv[x], "-help") == 0) { h = 1; }
    else if (strcmp(argv[x], "--help") == 0) { h = 1; }
  }
  if (f == 1 && p == 1) {
    printf("can't specify both -f and -p"); exit(-1);
  }
  else if (d == 1 && b == 1) {
    printf("can't specify both -d and -b"); exit(-1);
  }
  else if (q == 1 && v == 1) {
    printf("can't specify both -q and -v"); exit(-1);
  }
  else if (q == 1 && s == 1) {
    printf("can't specify both -q and -s"); exit(-1);
  }
  else if (s == 1 && v == 1) {
    printf("can't specify both -s and -v"); exit(-1);
  }
  else if (q == 1 && n == 1) {
    printf("can't specify both -q and -n"); exit(-1);
  }
  else if (s == 1 && n == 1) {
    printf("can't specify both -s and -n"); exit(-1);
  }
  else if (v == 1 && n == 1) {
    printf("can't specify both -v and -n"); exit(-1);
  }

  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-f") == 0) {
      if (args > x) { filename = argv[x + 1]; }
      else { printf("need -f name_of_configuration_file"); exit(-1); }
    }
  }
  for (x = 1; x <= args; x++) {
    if (strcmp(argv[x], "-p") == 0) {
      if (args > x) { profile = argv[x + 1]; }
      else { printf("need -p name_of_profile"); exit(-1); }
    }
  }

  if (h == 1) {
    puts("Usage: joytran [option]\n");

    puts("-h/--help               help (this)");
    puts("-s / -q / -n / -v       silent / quiet / normal / verbose");
    puts("-b / -d                 background / daemon");
    puts("-f file / -p name       config_file / profile\n");

    puts("mail bug reports and suggestions to beyert@cs.ucr.edu");
    exit(0);
  }

  if (v == 1) { verbosity = 2; }
  else if (q == 1) { verbosity = 0; }
  else if (s == 1) { verbosity = -1; }
  else { verbosity = 1; }

  if (p == 0) {
    profile = "default";
  }

  if (f == 0) {
    filename = getenv("HOME");
    strcat(filename, "/.joytran");
    strcat(filename, "/profiles/");
    strcat(filename, profile);
  }

  want_daemon = 0;
  if (d == 1) { want_daemon = 1; }
  else if (b == 1) { want_daemon = 0; }

  return 0;
}
